Struct Sier
Source #[repr(transparent)]
pub struct Sier(pub u32);
Transmit Data Interrupt Enable.
Transmit Data Interrupt Enable.
Receive Data Interrupt Enable.
Receive Data Interrupt Enable.
Address Valid Interrupt Enable.
Address Valid Interrupt Enable.
Transmit ACK Interrupt Enable.
Transmit ACK Interrupt Enable.
Repeated Start Interrupt Enable.
Repeated Start Interrupt Enable.
Stop Detect Interrupt Enable.
Stop Detect Interrupt Enable.
Bit Error Interrupt Enable.
Bit Error Interrupt Enable.
FIFO Error Interrupt Enable.
FIFO Error Interrupt Enable.
Address Match 0 Interrupt Enable.
Address Match 0 Interrupt Enable.
Address Match 1 Interrupt Enable.
Address Match 1 Interrupt Enable.
General Call Interrupt Enable.
General Call Interrupt Enable.
SMBus Alert Response Interrupt Enable.
SMBus Alert Response Interrupt Enable.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.